=======
Credits
=======

This package was inspired by GAmphetamine.js.

Development Lead
----------------

* Martin Roelfs <martinroelfs@yahoo.com>

Contributors
------------

None yet. Why not be the first?
